@@ -148,7 +148,7 @@ class CERNGroup(Group):
                     'instituteName',
                     'telephone1',
                     'primaryAccountEmail',
-                    'cernPersonId',
+                    'personId',
                 ],
                 'recursive': 'true'
             }
@@ -235,7 +235,7 @@ class CERNIdentityProvider(IdentityProvider):
         data['telephone1'] = self.settings['phone_prefix'] + phone
 
     def _extract_extra_data(self, data, default=None):
-        return {'cern_person_id': normalize_cern_person_id(data.pop('cernPersonId', default))}
+        return {'cern_person_id': normalize_cern_person_id(data.pop('personId', default))}
 
     def get_identity_from_auth(self, auth_info):
         upn = auth_info.data.get('sub')
@@ -340,7 +340,7 @@ class CERNIdentityProvider(IdentityProvider):
                 'instituteName',
                 'telephone1',
                 'primaryAccountEmail',
-                'cernPersonId',
+                'personId',
             ],
         }
 
@@ -378,6 +378,7 @@ class CERNIdentityProvider(IdentityProvider):
 
     def get_identity_groups(self, identifier):
         with self._get_api_session() as api_session:
+            identifier = identifier.replace('/', '%2F')  # edugain identifiers sometimes contain slashes
             resp = api_session.get(f'{self.authz_api_base}/api/v1.0/IdentityMembership/{identifier}/precomputed')
             if resp.status_code == 404 or resp.status_code == 500:
                 return set()
@@ -446,7 +447,7 @@ class CERNIdentityProvider(IdentityProvider):
                 'instituteName',
                 'telephone1',
                 'primaryAccountEmail',
-                'cernPersonId',
+                'personId',
             ],
         }
         resp = self.authlib_client.get(f'{self.authz_api_base}/api/v1.0/Identity/current', token=user_api_token,
@@ -499,10 +500,11 @@ class CERNIdentityProvider(IdentityProvider):
                 'instituteName',
                 'telephone1',
                 'primaryAccountEmail',
-                'cernPersonId',
+                'personId',
             ]
         }
         with self._get_api_session() as api_session:
+            identifier = identifier.replace('/', '%2F')  # edugain identifiers sometimes contain slashes
             resp = api_session.get(f'{self.authz_api_base}/api/v1.0/Identity/{identifier}', params=params)
             resp.raise_for_status()
             data = resp.json()
@@ -514,12 +516,12 @@ class CERNIdentityProvider(IdentityProvider):
             ('given_name', 'firstName'),
             ('family_name', 'lastName'),
             ('email', 'primaryAccountEmail'),
-            ('cern_person_id', 'cernPersonId'),
+            ('cern_person_id', 'personId'),
         ]
 
         for token_field, api_field in fields_to_compare:
-            token_value = str(token_data.get(token_field, ''))
-            api_value = str(api_data.get(api_field, ''))
+            token_value = str(token_data.get(token_field) or '<missing>')
+            api_value = str(api_data.get(api_field) or '<missing>')
             if token_value != api_value:
                 self.logger.warning('Field %s mismatch for %s: %s in id_token, %s in authz api',
                                     token_field, token_data['sub'], token_value, api_value)
